Method: INotify::Event#flags
- Defined in:
- lib/rb-inotify/event.rb
#flags ⇒ Array<Symbol>
Returns the flags that describe this event.
This is generally similar to the input to Notifier#watch,
except that it won't contain options flags nor :all_events,
and it may contain one or more of the following flags:
:unmount
: The filesystem containing the watched file or directory was unmounted.
:ignored
: The watcher was closed, or the watched file or directory was deleted.
:isdir
: The subject of this event is a directory.
86 87 88 |
# File 'lib/rb-inotify/event.rb', line 86 def flags @flags ||= Native::Flags.from_mask(@native[:mask]) end |